@@ -18,6 +18,7 @@ firstname: Nero
 familyname: Yuzurizaki
 birthday: August 28
 voiced_by: Sora Tokui
+nickname_voiced_by: soramaru
 toys: Direct Hack
 
 @@ ja
@@ -26,4 +27,5 @@ firstname: ネロ
 familyname: 譲崎
 birthday: 8/28
 voiced_by: 徳井 青空
+nickname_voiced_by: そらまる
 toys: ダイレクトハック
